.. _api:

===
API
===

.. currentmodule:: pytoshop

User api
--------

.. autosummary::
   :toctree: _generated

   read
   user.nested_layers

Objects
-------

.. autosummary::
   :toctree: _generated

   blending_range
   core
   color_mode
   image_data
   image_resources
   layers
   path
   tagged_block

Enums
-----

.. autosummary::
   :toctree: _generated

   enums

Codecs
------

.. autosummary::
   :toctree: _generated

   codecs

Utilities
---------

.. autosummary::
   :toctree: _generated

   util
